---
title: "Example dashboards built using Power Bpy"
listing: 
  contents: example_dashboards 
  sort: "date desc" 
  type: default
  categories: true 
page-layout: full
format:
  html: 
    comments: false
---
::: {.column-page}

:::